A set of proc macros used for policy lang text and identifier literals.
Do not use this crate directly. Use the macros from aranya-policy-text
or a re-export from e.g. aranya-policy-ast or aranya-policy-vm.
A set of proc macros used for policy lang text and identifier literals.
Do not use this crate directly. Use the macros from aranya-policy-text
or a re-export from e.g. aranya-policy-ast or aranya-policy-vm.